@@ -276,8 +276,11 @@ typedef struct _ListGame {
     GameInfo gameInfo;      /*  Note that some entries may be NULL. */
 } ListGame;
  
+extern int storedGames;
+extern int opponentKibitzes;
 extern ChessSquare gatingPiece;
 extern List gameList;
+extern int lastLoadGameNumber;
 void ClearGameInfo P((GameInfo *));
 int GameListBuild P((FILE *));
 void GameListInitGameInfo P((GameInfo *));
@@ -398,7 +401,7 @@ typedef struct {
 } ChessProgramStats;
 
 extern ChessProgramStats_Move pvInfoList[MAX_MOVES];
-extern int shuffleOpenings;
+extern Boolean shuffleOpenings;
 extern ChessProgramStats programStats;
 extern int opponentKibitzes; // used by wengineo.c
 extern int errorExitStatus;
