@@ -32,8 +32,6 @@
 #include <ctype.h>
 #endif /* def SEL_FILE_IGNORE_CASE */
 
-#include "selfile.h"
-
 #ifdef HAVE_DIRENT_H
 #include <dirent.h>
 #else
@@ -43,6 +41,8 @@
 
 #include <sys/stat.h>
 
+#include "selfile.h"
+
 #ifdef SEL_FILE_IGNORE_CASE
 int
 SFcompareEntries(p, q)
@@ -121,14 +121,13 @@ SFgetDir(dir)
 	(void) stat(".", &statBuf);
 	dir->mtime = statBuf.st_mtime;
 
-	(void) readdir(dirp);	/* throw away "." */
-
-#ifndef S_IFLNK
-	(void) readdir(dirp);	/* throw away ".." */
-#endif /* ndef S_IFLNK */
-
 	while (dp = readdir(dirp)) {
+
 		struct stat statBuf;
+		if(!strcmp(dp->d_name, ".")) continue; /* Throw away "." */
+		if(!strcmp(dp->d_name, "..")) continue; /* Throw away ".." */
+#ifndef S_IFLNK
+#endif /* ndef S_IFLNK */
 		if (i >= alloc) {
 			alloc = 2 * (alloc + 1);
 			result = (SFEntry *) XtRealloc((char *) result,
