@@ -248,16 +248,41 @@ AdaptMenu()
 	DrawMenuBar(hwndMain);
 }
 
+#ifdef NVDA
+
+#include "nvdaController.h"
+
+void
+SayNVDA(char *text, BOOL interrupt)
+{
+	static wchar_t buf[8000];
+        if(interrupt) nvdaController_cancelSpeech();
+	MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, text, -1, buf, 8000);
+        nvdaController_speakText(buf);
+}
+
+
+#undef UNICODE
+
+#endif
+
 BOOL
 InitJAWS()
 {	// to be called at beginning of WinMain, after InitApplication and InitInstance
-	HINSTANCE hApi = LoadLibrary("jfwapi32.dll");
-	if(!hApi) {
+#ifdef NVDA
+	RealSayString = (PSAYSTRING) &SayNVDA; // assume NVDA
+	if(nvdaController_testIfRunning()) {  // no NVDA; try JAWS
+#else
+	{
+#endif
+	    HINSTANCE hApi = LoadLibrary("jfwapi32.dll");
+	    if(!hApi) { // no interface to JAWS either
 		DisplayInformation("Missing jfwapi32.dll");
 		return (FALSE);
+	    }
+	    RealSayString = (PSAYSTRING)GetProcAddress(hApi, "JFWSayString");
 	}
 
-	RealSayString = (PSAYSTRING)GetProcAddress(hApi, "JFWSayString");
 	if(!RealSayString) {
 		DisplayInformation("SayString returned a null pointer");
 		return (FALSE);
@@ -336,7 +361,7 @@ KeyboardEvent(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 		if(currentPiece != EmptySquare) {
 			char buf[MSG_SIZ];
 			n = boards[currentMove][fromY][1];
-			snprintf(buf, MSG_SIZ, "%d %s%s", n, PieceToName(currentPiece,0), n == 1 ? "" : "s");
+			snprintf(buf, MSG_SIZ, "%d %s%s", n, _(PieceToName(currentPiece,0)), n == 1 ? "" : "s");
 			SayString(buf, FALSE);
 		}
 		SayString(" ", TRUE);
@@ -346,7 +371,7 @@ KeyboardEvent(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 		if(currentPiece != EmptySquare) {
 			char buf[MSG_SIZ];
 			n = boards[currentMove][fromY][BOARD_WIDTH-2];
-			snprintf(buf, MSG_SIZ,"%d %s%s", n, PieceToName(currentPiece,0), n == 1 ? "" : "s");
+			snprintf(buf, MSG_SIZ,"%d %s%s", n, _(PieceToName(currentPiece,0)), n == 1 ? "" : "s");
 			SayString(buf, FALSE);
 		}
 		SayString(" ", TRUE);
@@ -356,8 +381,8 @@ KeyboardEvent(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 		xchar = SquareToChar(fromX);
 		ynum = SquareToNum(fromY);
 		if(currentPiece != EmptySquare) {
-		  snprintf(buf, MSG_SIZ, "%s %s %s", xchar, ynum, piece);
-		} else snprintf(buf, MSG_SIZ, "%s %s", xchar, ynum);
+		  snprintf(buf, MSG_SIZ, "%s %s %s", _(xchar), _(ynum), _(piece));
+		} else snprintf(buf, MSG_SIZ, "%s %s", _(xchar), _(ynum));
 		SayString(buf, FALSE);
 		SayString(" ", TRUE);
 	}
