@@ -31,6 +31,8 @@
 #define IDM_TimeControl                 131
 #define IDM_LoadOptions                 132
 #define IDM_SaveOptions                 133
+#define IDM_EditGame2                   134
+#define IDM_EditPosition2               135
 #define IDM_CommPort                    147
 #define IDM_EditComment                 148
 #define IDM_LoadNextGame                149
@@ -44,15 +46,22 @@
 #define IDM_TruncateGame                158
 #define IDM_MoveNow                     159
 #define IDM_RetractMove                 160
+#define IDM_Upload                      161
 #define IDM_MailMove                    164
 #define IDM_ReloadCMailMsg              165
 #define IDM_Book                        166
 #define IDM_AboutGame                   167
+#define IDM_EditServers                 169
 #define IDM_ShowGameList                170
 #define IDM_EditTags                    171
+#define IDM_Tags                        172
+#define IDM_Comment                     173
 #define IDM_Debug                       174
+#define IDM_EditProgs1                  175
+#define IDM_EditProgs2                  176
 #define IDM_AnalysisMode                177
 #define IDM_AnalyzeFile                 178
+#define IDM_Annotate                    179
 #define IDM_CopyGame                    180
 #define IDM_PasteGame                   181
 #define IDM_CopyPosition                182
@@ -61,6 +70,7 @@
 #define IDM_TypeInName                  185  
 #define IDM_MachineBoth                 186  
 #define IDM_MuteSounds                  187
+#define IDM_Match                       188
 #define OPT_TCtext1                     202
 #define OPT_TCTime                      203
 #define OPT_TCtext2                     204
@@ -89,6 +99,9 @@
 #define OPT_TCTime2                     409
 #define OPT_TCOdds1                     410
 #define OPT_TCOdds2                     411
+#define OPT_TCUseFixed                  412
+#define OPT_TCFixed                     413
+#define OPT_TCftext                     414
 #define DLG_PremoveOptions              450
 #define DLG_GeneralOptions              453
 #define DLG_IcsOptions                  454
@@ -424,6 +437,7 @@
 #define OPT_OutOfBookInfo               1436
 #define OPT_ExtraInfoInMoveHistory      1437
 #define OPT_HighlightMoveArrow          1438
+#define OPT_AutoLogo			1439
 #define IDC_BUTTON1                     1440
 #define IDC_BrowseForPolyglotDir        1440
 #define IDC_BrowseForEGTB               1441
@@ -451,6 +465,9 @@
 #define IDC_OwnBook1                    1471
 #define IDC_OwnBook2                    1472
 #define IDC_Cores                       1473
+#define IDC_BookDep                     1474
+#define IDC_BookStr                     1475
+#define IDC_Games                       1476
 #define DLG_NewVariant                  1500
 #define OPT_VariantGothic               1501
 #define OPT_VariantCrazyhouse           1502
@@ -481,6 +498,8 @@
 #define OPT_VariantGreat                1527
 #define OPT_VariantTwilight             1528
 #define OPT_VariantMakruk               1529
+#define OPT_VariantSChess               1530
+#define OPT_VariantSpartan              1531
 #define IDC_Files                       1550
 #define IDC_Ranks                       1551
 #define IDC_Holdings                    1552
@@ -503,12 +522,80 @@
 #define IDC_Clear			1725
 #define IDC_Send			1726
 #define IDM_NewChat			1727
+#define IDC_Focus1			1730
+#define IDC_Focus2			1731
+#define IDC_Focus3			1732
+#define IDC_Focus4			1733
+#define OPT_SeekGraph			1750
+#define OPT_AutoRefresh			1751
+#define OPT_BgObserve			1752
+#define OPT_DualBoard			1753
+#define OPT_SmartMove			1754
+#define OPT_StartupChatBoxes		1755
+#define OPT_AutoKibitz			1756
 #define IDC_SPECIFY_ENG_STATIC          1814
 #define IDC_SPECIFY_SERVER_STATIC       1815
 #define OPT_MESS                        1818
 #define IDM_Engine1Options		1890
 #define IDM_Engine2Options		1891
 #define IDC_STATIC                      -1
+// static strings that were made dynamic to allow run-time translation
+#define IDC_Babble			1900
+#define GPB_Factors			1901
+#define IDC_Factor1			1902
+#define IDC_Factor2			1903
+#define IDC_Directories			1904
+#define IDC_IndexNr			1905
+#define IDC_Port			1906
+#define IDC_Rate			1907
+#define IDC_Bits			1908
+#define IDC_Parity			1909
+#define IDC_Stop			1910
+#define IDC_Flow			1911
+#define IDC_ChessBoard			1912
+#define IDC_Welcome			1913
+#define IDC_Index			1914
+#define IDC_Event			1915
+#define IDC_Sec				1916
+#define IDC_Boxes			1917
+#define GPB_Premove			1918
+#define GPB_General			1919
+#define GPB_Colors			1920
+#define GPB_Alarm			1921
+#define IDC_Light			1922
+#define IDC_Dark			1923
+#define IDC_White			1924
+#define IDC_Black			1925
+#define IDC_High			1926
+#define IDC_PreHigh			1927
+#define GPB_Size			1928
+#define IDC_Height			1929
+#define IDC_Width			1930
+#define IDC_Hand			1931
+#define IDC_Pieces			1932
+#define IDC_Def				1933
+#define GPB_Board			1934
+#define GPB_Current			1935
+#define GPB_All				1936
+#define IDC_Partner			1937
+#define IDC_Draw			1938
+#define IDC_Threshold			1939
+#define IDC_Moves			1940
+#define IDC_Centi			1941
+#define IDC_Rule			1942
+#define IDC_Repeats			1943
+#define GPB_Adjudications		1944	
+#define GPB_Apply			1945
+#define IDC_PolyDir			1946
+#define IDC_Hash			1947
+#define IDC_Path			1948
+#define IDC_Cache			1949
+#define IDC_CPU				1950
+#define IDC_Depth			1951
+#define IDC_Variation			1952
+#define IDC_DefGames			1953
+#define GPB_Variant			1954
+
 
 // Next default values for new objects
 // 
