@@ -184,6 +184,7 @@ DesignOptionDialog(ChessProgramState *cps)
 	// look if we hit a group of options having names that start with the same word
 	int groupSize = 1, groupNameLength = 50;
 	sscanf(cps->option[k].name, "%s", buf); // get first word of option name
+#ifndef JAWS
 	while(k + groupSize < cps->nrOptions &&
 	      strstr(cps->option[k+groupSize].name, buf) == cps->option[k+groupSize].name) {
 		int j;
@@ -193,6 +194,7 @@ DesignOptionDialog(ChessProgramState *cps)
 		groupSize++;
 
 	}
+#endif
 	if(groupSize > 3) {
 		// We found a group to terminates the current section
 		LayoutOptions(n, k, "", cps->option); // flush all solitary options appearing before the group
@@ -250,10 +252,16 @@ SetOptionValues(HWND hDlg, ChessProgramState *cps)
 
     for(i=0; i<layout+buttons; i++) {
 	int j=layoutList[i];
-	if(j == -2) SetDlgItemText( hDlg, 2000+2*i, ". . ." );
+#ifdef JAWS
+	if(j <= -2) SetDlgItemText( hDlg, 2000+2*i, "browse" );
+#else
+	if(j <= -2) SetDlgItemText( hDlg, 2000+2*i, ". . ." );
+#endif
 	if(j<0) continue;
 	name = cps->option[j].name;
+#ifndef JAWS
 	if(strstr(name, "Polyglot ") == name) name += 9;
+#endif
 	SetDlgItemText( hDlg, 2000+2*i, name );
 //if(appData.debugMode) fprintf(debugFP, "# %s = %d\n",cps->option[j].name, cps->option[j].value );
 	switch(cps->option[j].type) {
@@ -370,7 +378,7 @@ LRESULT CALLBACK SettingsProc(HWND hDlg, UINT message, WPARAM wParam, LPARAM lPa
 //        CenterWindow(hDlg, GetWindow(hDlg, GW_OWNER));
 	SetOptionValues(hDlg, activeCps);
 
-//        SetFocus(GetDlgItem(hDlg, IDC_NFG_Edit));
+        SetFocus(GetDlgItem(hDlg, IDCANCEL));
 
         break;
 
@@ -425,7 +433,6 @@ LRESULT CALLBACK SettingsProc(HWND hDlg, UINT message, WPARAM wParam, LPARAM lPa
 			SetDlgItemText( hDlg, i+3, buf );
 		    }
 		}
-      return TRUE;
 		if(j < 0) break;
 		if( activeCps->option[j].type  == SaveButton)
 		     GetOptionValues(hDlg, activeCps);
@@ -491,7 +498,7 @@ void AddOption(int x, int y, Control type, int i)
 	case Button:
 	case ResetButton:
 	case SaveButton:
-	    AddControl(x-2, y, 65, 13, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD, i);
+	    AddControl(x-2, y, 65, 13, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD | WS_TABSTOP, i);
 	case Message:
 	default:
 	    break;
@@ -502,7 +509,7 @@ void AddOption(int x, int y, Control type, int i)
 void
 CreateDialogTemplate(int *layoutList, int nr, ChessProgramState *cps)
 {
-    int i, j, x=1, y=0, buttonRows, breakPoint = -1, k=0;
+    int i, ii, j, x=1, y=0, buttonRows, breakPoint = -1, k=0;
 
     template.header.cdit = 0;
     template.header.cx = 307;
@@ -512,31 +519,32 @@ CreateDialogTemplate(int *layoutList, int nr, ChessProgramState *cps)
 	template.header.cx = 625;
     }
 
-    for(i=0; i<nr; i++) {
-	if(k < groups && i == boxList[k]) {
+    for(ii=0; ii<nr; ii++) {
+	i = ii^1; if(i == nr) i = ii; // if two on one line, swap order of treatment, to get good (left to right) tabbing order.
+	if(k < groups && ii == boxList[k]) {
 	    y += 10;
 	    AddControl(x+2, y+13*(i>>1)-2, 301, 13*(boxList[k+1]-boxList[k]>>1)+8,
 						0x0082, WS_VISIBLE | WS_CHILD | SS_BLACKFRAME, 2400);
 	    AddControl(x+60, y+13*(i>>1)-6, 10*groupNameList[k]/3, 10,
-						0x0082, SS_ENDELLIPSIS | WS_VISIBLE | WS_CHILD, 2*(i+MAX_OPTIONS));
+						0x0082, SS_ENDELLIPSIS | WS_VISIBLE | WS_CHILD, 2*(ii+MAX_OPTIONS));
 	}
 	j = layoutList[i];
 	if(j >= 0)
 	    AddOption(x+155-150*(i&1), y+13*(i>>1)+5, cps->option[j].type, 2*i);
-	if(k < groups && i+1 == boxList[k+1]) {
+	if(k < groups && ii+1 == boxList[k+1]) {
 	    k += 2; y += 4;
 	}
-	if(i+1 == breakPoint) { x += 318; y = -13*(breakPoint>>1); }
+	if(ii+1 == breakPoint) { x += 318; y = -13*(breakPoint>>1); }
     }
     // add butons at the bottom of dialog window
     y += 13*(nr>>1)+5;
 
-    AddControl(x+225, y+18*(buttonRows-1), 30, 15, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD, IDOK-2000);
-    AddControl(x+260, y+18*(buttonRows-1), 40, 15, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD, IDCANCEL-2000);
     for(i=0; i<buttons; i++) {
-	AddControl(x+70*(i%4)+5, y+18*(i/4), 65, 15, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD, 2*(nr+i));
+	AddControl(x+70*(i%4)+5, y+18*(i/4), 65, 15, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD | WS_TABSTOP, 2*(nr+i));
 	layoutList[nr+i] = buttonList[i];
     }
+    AddControl(x+225, y+18*(buttonRows-1), 30, 15, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD | WS_TABSTOP, IDOK-2000);
+    AddControl(x+260, y+18*(buttonRows-1), 40, 15, 0x0080, BS_PUSHBUTTON | WS_VISIBLE | WS_CHILD | WS_TABSTOP, IDCANCEL-2000);
     template.title[8] = cps == &first ? '1' :  '2';
     template.header.cy = y += 18*buttonRows+2;
     template.header.style &= ~WS_VSCROLL;
