@@ -1,7 +1,7 @@
 /*
  * xedittags.c -- Tags edit window, part of X front end for XBoard
  *
- * Copyright 1995, 2009, 2010 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
@@ -91,21 +91,10 @@ extern char *getenv();
 # define N_(s)  s
 #endif
 
-extern Widget formWidget, shellWidget, boardWidget, menuBarWidget;
-extern Display *xDisplay;
-extern int squareSize;
-extern Pixmap xMarkPixmap;
-extern char *layoutName;
-
 Position tagsX = -1, tagsY = -1;
 int tagsUp = False, editTagsUp = False;
 Widget tagsShell, editTagsShell;
 
-static Arg layoutArgs[] = {
-    { XtNborderWidth, 0 },
-    { XtNdefaultDistance, 0 }
-};
-
 void TagsCallback(w, client_data, call_data)
      Widget w;
      XtPointer client_data, call_data;
@@ -343,14 +332,15 @@ void TagsPopUp(tags, msg)
 
     tagsUp = True;
     j = 0;
-    XtSetArg(args[j], XtNleftBitmap, None); j++;
-    XtSetValues(XtNameToWidget(menuBarWidget, "menuMode.Edit Tags"),
+    XtSetArg(args[j], XtNleftBitmap, xMarkPixmap); j++;
+    XtSetValues(XtNameToWidget(menuBarWidget, "menuView.Show Tags"),
 		args, j);
 }
 
 
-void EditTagsPopUp(tags)
+void EditTagsPopUp(tags, dest)
      char *tags;
+     char **dest;
 {
     Widget textw;
     Arg args[16];
@@ -376,7 +366,7 @@ void EditTagsPopUp(tags)
     editTagsUp = True;
     j = 0;
     XtSetArg(args[j], XtNleftBitmap, xMarkPixmap); j++;
-    XtSetValues(XtNameToWidget(menuBarWidget, "menuMode.Edit Tags"),
+    XtSetValues(XtNameToWidget(menuBarWidget, "menuView.Show Tags"),
 		args, j);
 }
 
@@ -402,7 +392,7 @@ void TagsPopDown()
     tagsUp = editTagsUp = False;
     j = 0;
     XtSetArg(args[j], XtNleftBitmap, None); j++;
-    XtSetValues(XtNameToWidget(menuBarWidget, "menuMode.Edit Tags"),
+    XtSetValues(XtNameToWidget(menuBarWidget, "menuView.Show Tags"),
 		args, j);
 }
 
