@@ -93,15 +93,9 @@ extern char *getenv();
 
 void SetFocus P((Widget w, XtPointer data, XEvent *event, Boolean *b));
 
-extern Widget formWidget, shellWidget, boardWidget, menuBarWidget, gameListShell;
-extern Display *xDisplay;
-extern int squareSize;
-extern Pixmap xMarkPixmap;
-extern char *layoutName;
-
 static Widget filterText;
 static char filterString[MSG_SIZ];
-static int listLength;
+static int listLength, page;
 
 char gameListTranslations[] =
   "<Btn1Up>(2): LoadSelectedProc(0) \n \
@@ -115,6 +109,8 @@ char gameListTranslations[] =
 char filterTranslations[] =
   "<Key>Return: SetFilterProc() \n";
 
+char *dummyList[] = { N_("no games matched your request"), NULL };
+
 typedef struct {
     Widget shell;
     Position x, y;
@@ -126,11 +122,6 @@ typedef struct {
 } GameListClosure;
 static GameListClosure *glc = NULL;
 
-static Arg layoutArgs[] = {
-    { XtNborderWidth, 0 },
-    { XtNdefaultDistance, 0 }
-};
-
 Widget
 GameListCreate(name, callback, client_data)
      char *name;
@@ -180,7 +171,6 @@ GameListCreate(name, callback, client_data)
       XtCreateManagedWidget("viewport", viewportWidgetClass, form, args, j);
 
     j = 0;
-    XtSetArg(args[j], XtNlist, glc->strings);  j++;
     XtSetArg(args[j], XtNdefaultColumns, 1);  j++;
     XtSetArg(args[j], XtNforceColumns, True);  j++;
     XtSetArg(args[j], XtNverticalList, True);  j++;
@@ -355,14 +345,22 @@ GameListPrepare()
     return listLength;
 }
 
+static char *list[1003];
+
 static void
-GameListReplace()
+GameListReplace(int page)
 {
   // filter: put in separate routine, to make callable from call-back
   Widget listwidg;
+  char **st=list;
+  int i;
 
+  if(page) *st++ = _("previous page"); else if(listLength > 1000) *st++ = "";
+  for(i=0; i<1000; i++) if( !(*st++ = glc->strings[page+i]) ) break;
+  if(page + 1000 <= listLength) *st++ = _("next page");
+  *st = NULL;
   listwidg = XtNameToWidget(glc->shell, "*form.viewport.list");
-  XawListChange(listwidg, glc->strings, 0, 0, True);
+  XawListChange(listwidg, listLength ? list : dummyList, 0, 0, True);
   XawListHighlight(listwidg, 0);
 }
 
@@ -397,7 +395,7 @@ GameListCallback(w, client_data, call_data)
 	}
     } else if (strcmp(name, _("next")) == 0) {
 	index = rs->list_index + 1;
-	if (index >= listLength) {
+	if (index >= listLength || !list[index]) {
 	    DisplayError(_("Can't go forward any further"), 0);
 	    return;
 	}
@@ -416,15 +414,19 @@ GameListCallback(w, client_data, call_data)
 	XtGetValues(filterText, args, j);
         safeStrCpy(filterString, name, sizeof(filterString)/sizeof(filterString[0]));
 	XawListHighlight(listwidg, 0);
-        if(GameListPrepare()) GameListReplace(); // crashes on empty list...
+        GameListPrepare(); GameListReplace(0);
         return;
     }
-    index = atoi(glc->strings[index])-1; // [HGM] filter: read true index from sequence nr of line
+#if 1
+    index = atoi(list[index])-1; // [HGM] filter: read true index from sequence nr of line
     if (cmailMsgLoaded) {
 	CmailLoadGame(glc->fp, index + 1, glc->filename, True);
     } else {
 	LoadGame(glc->fp, index + 1, glc->filename, True);
     }
+#else
+    printf("This code should have been unreachable. Please report bug!\n");
+#endif
 }
 
 void
@@ -460,13 +462,15 @@ GameListPopUp(fp, filename)
     if (glc->shell == NULL) {
 	glc->shell = GameListCreate(filename, GameListCallback, glc);
     } else {
-        GameListReplace(); // [HGM] filter: code put in separate routine
 	j = 0;
 	XtSetArg(args[j], XtNiconName, (XtArgVal) filename);  j++;
 	XtSetArg(args[j], XtNtitle, (XtArgVal) filename);  j++;
 	XtSetValues(glc->shell, args, j);
     }
 
+    page = 0;
+    GameListReplace(0); // [HGM] filter: code put in separate routine
+
     XtPopup(glc->shell, XtGrabNone);
     glc->up = True;
     j = 0;
@@ -535,6 +539,18 @@ LoadSelectedProc(w, event, prms, nprms)
     rs = XawListShowCurrent(listwidg);
     index = rs->list_index;
     if (index < 0) return;
+    if(page && index == 0) {
+        page -= 1000;
+        if(page < 0) page = 0; // safety
+        GameListReplace(page);
+       return;
+    }
+    if(index == 1001) {
+        page += 1000;
+        GameListReplace(page);
+       return;
+    }
+
     if(direction != 0) {
 	index += direction;
 	if(direction == -2) index = 0;
@@ -543,7 +559,8 @@ LoadSelectedProc(w, event, prms, nprms)
 	XawListHighlight(listwidg, index);
 	return;
     }
-    index = atoi(glc->strings[index])-1; // [HGM] filter: read true index from sequence nr of line
+    if(!list[index]) return;
+    index = atoi(list[index])-1; // [HGM] filter: read true index from sequence nr of line
     if (cmailMsgLoaded) {
 	CmailLoadGame(glc->fp, index + 1, glc->filename, True);
     } else {
@@ -565,7 +582,7 @@ SetFilterProc(w, event, prms, nprms)
         XtSetArg(args[j], XtNstring, &name);  j++;
 	XtGetValues(filterText, args, j);
         safeStrCpy(filterString, name, sizeof(filterString)/sizeof(filterString[0]));
-        if(GameListPrepare()) GameListReplace(); // crashes on empty list...
+        GameListPrepare(); GameListReplace(0);
 	list = XtNameToWidget(glc->shell, "*form.viewport.list");
 	XawListHighlight(list, 0);
         j = 0;
@@ -608,7 +625,7 @@ GameListHighlight(index)
     int i=0; char **st;
     if (glc == NULL || !glc->up) return;
     listwidg = XtNameToWidget(glc->shell, "*form.viewport.list");
-    st = glc->strings;
+    st = list;
     while(*st && atoi(*st)<index) st++,i++;
     XawListHighlight(listwidg, i);
 }
