@@ -1,7 +1,7 @@
 /*
  * xgamelist.h -- Game list window, part of X front end for XBoard
  *
- * Copyright 1995, 2009, 2010 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -27,5 +27,8 @@ void ShowGameListProc P((Widget w, XEvent *event,
 			 String *prms, Cardinal *nprms));
 void LoadSelectedProc P((Widget w, XEvent *event,
 			 String *prms, Cardinal *nprms));
+void SetFilterProc P((Widget w, XEvent *event,
+			 String *prms, Cardinal *nprms));
 
+extern Widget gameListShell;
 #endif /* _XGAMEL_H */
