@@ -2,10 +2,10 @@
  * zippy.c -- Implements Zippy the Pinhead chess player on ICS in XBoard
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard,
- * Massachusetts. 
+ * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -146,7 +146,7 @@ void ZippyInit()
     if ( p != NULL ) {
       appData.zippyAcceptOnly = p;
     }
-    
+
     /* Should Zippy use "i" command? */
     /* Defaults to 1=true */
     p = getenv("ZIPPYUSEI");
@@ -199,7 +199,7 @@ void ZippyInit()
     if (p != NULL) {
       appData.zippyVariants = p;
     }
-    strcpy(first.variants, appData.zippyVariants);
+    safeStrCpy(first.variants, appData.zippyVariants, sizeof(first.variants)/sizeof(first.variants[0]));
 
     srandom(time(NULL));
 }
@@ -209,7 +209,7 @@ void ZippyInit()
  */
 
 
-char *swifties[] = { 
+char *swifties[] = {
     "i acclaims:", "i admonishes:", "i advertises:", "i advises:",
     "i advocates:", "i affirms:", "i alleges:", "i anathematizes:",
     "i animadverts:", "i announces:", "i apostrophizes:",
@@ -251,7 +251,7 @@ char *swifties[] = {
     "i hosannas:", "i howls:", "i hums:", "i hypothecates:",
     "i hypothesizes:", "i imagines:", "i implies:", "i implores:",
     "i imprecates:", "i indicates:", "i infers:",
-    "i informs everyone:",  "i instructs:", "i interjects:", 
+    "i informs everyone:",  "i instructs:", "i interjects:",
     "i interposes:", "i intimates:", "i intones:", "i introspects:",
     "i inveighs:", "i jabbers:", "i japes:", "i jests:", "i jibes:",
     "i jives:", "i jokes:", "i joshes:", "i keens:", "i laments:",
@@ -304,7 +304,7 @@ char *swifties[] = {
 
 #define MAX_SPEECH 250
 
-void Speak(how, whom) 
+void Speak(how, whom)
      char *how, *whom;
 {
     static FILE *zipfile = NULL;
@@ -315,7 +315,7 @@ void Speak(how, whom)
     char  *p;
     int c, speechlen;
     Boolean done;
-		
+
     if (strcmp(how, "shout") == 0) {
 	now = time((time_t *) NULL);
 	if (now - lastShout < 1*60) return;
@@ -334,7 +334,7 @@ void Speak(how, whom)
 	}
 	fstat(fileno(zipfile), &zipstat);
     }
-		
+
     for (;;) {
 	fseek(zipfile, (unsigned) random() % zipstat.st_size, 0);
 	do {
@@ -349,7 +349,7 @@ void Speak(how, whom)
 
     /* Don't use ics_prefix; we need to let FICS expand the alias i -> it,
        but use the real command "i" on ICC */
-    strcpy(zipbuf, how);
+    safeStrCpy(zipbuf, how, sizeof(zipbuf)/sizeof(zipbuf[0]));
     strcat(zipbuf, " ");
     if (whom != NULL) {
 	strcat(zipbuf, whom);
@@ -414,7 +414,7 @@ int ZippyControl(buf, i)
 
     /* Possibly reject Crafty as opponent */
     if (appData.zippyPlay && appData.zippyNoplayCrafty && forwardMostMove < 4
-	&& looking_at(buf, i, "* kibitzes: Hello from Crafty")) 
+	&& looking_at(buf, i, "* kibitzes: Hello from Crafty"))
     {
         player = StripHighlightAndTitle(star_match[0]);
 	if ((gameMode == IcsPlayingWhite &&
@@ -422,7 +422,7 @@ int ZippyControl(buf, i)
 	    (gameMode == IcsPlayingBlack &&
 	     StrCaseCmp(player, gameInfo.white) == 0)) {
 
-	  sprintf(reply, "%ssay This computer does not play Crafty clones\n%sabort\n%s+noplay %s\n",
+	  snprintf(reply, MSG_SIZ, "%ssay This computer does not play Crafty clones\n%sabort\n%s+noplay %s\n",
 		  ics_prefix, ics_prefix, ics_prefix, player);
 	  SendToICS(reply);
 	}
@@ -431,38 +431,38 @@ int ZippyControl(buf, i)
 
     /* If this is a computer, save the name.  Then later, once the */
     /* game is really started, we will send the "computer" notice to */
-    /* the engine.  */ 
+    /* the engine.  */
     if (appData.zippyPlay &&
 	looking_at(buf, i, "* is in the computer list")) {
 	int i;
 	for (i=0;i<num_opps;i++)
 	  if (!strcmp(opp_name[i],star_match[0])) break;
-	if (i >= num_opps) strcpy(opp_name[num_opps++],star_match[0]);
+	if (i >= num_opps) safeStrCpy(opp_name[num_opps++],star_match[0], sizeof(opp_name[num_opps])/sizeof(opp_name[num_opps][0]));
     }
     if (appData.zippyPlay && looking_at(buf, i, "* * is a computer *")) {
 	int i;
 	for (i=0;i<num_opps;i++)
 	  if (!strcmp(opp_name[i],star_match[1])) break;
-	if (i >= num_opps) strcpy(opp_name[num_opps++],star_match[1]);
+	if (i >= num_opps) safeStrCpy(opp_name[num_opps++],star_match[1], sizeof(opp_name[num_opps])/sizeof(opp_name[num_opps][0]));
     }
 
     /* Tells and says */
-    if (appData.zippyPlay && 
+    if (appData.zippyPlay &&
 	(looking_at(buf, i, "* offers to be your bughouse partner") ||
 	 looking_at(buf, i, "* tells you: [automatic message] I chose you"))) {
 	player = StripHighlightAndTitle(star_match[0]);
 	if (appData.zippyBughouse > 1 && first.initDone) {
-	    sprintf(reply, "%spartner %s\n", ics_prefix, player);
+	    snprintf(reply, MSG_SIZ,"%spartner %s\n", ics_prefix, player);
 	    SendToICS(reply);
 	    if (strcmp(zippyPartner, player) != 0) {
-		strcpy(zippyPartner, player);
-		SendToProgram(reply + strlen(ics_prefix), &first);
+	      safeStrCpy(zippyPartner, player, sizeof(zippyPartner)/sizeof(zippyPartner[0]));
+	      SendToProgram(reply + strlen(ics_prefix), &first);
 	    }
 	} else if (appData.zippyBughouse > 0) {
-	    sprintf(reply, "%sdecline %s\n", ics_prefix, player);
+	    snprintf(reply, MSG_SIZ, "%sdecline %s\n", ics_prefix, player);
 	    SendToICS(reply);
 	} else {
-	    sprintf(reply, "%stell %s This computer cannot play bughouse\n",
+	  snprintf(reply, MSG_SIZ, "%stell %s This computer cannot play bughouse\n",
 		    ics_prefix, player);
 	    SendToICS(reply);
 	}
@@ -472,10 +472,10 @@ int ZippyControl(buf, i)
     if (appData.zippyPlay && appData.zippyBughouse && first.initDone &&
 	looking_at(buf, i, "* agrees to be your partner")) {
 	player = StripHighlightAndTitle(star_match[0]);
-	sprintf(reply, "partner %s\n", player);
+	snprintf(reply, MSG_SIZ, "partner %s\n", player);
 	if (strcmp(zippyPartner, player) != 0) {
-	    strcpy(zippyPartner, player);
-	    SendToProgram(reply, &first);
+	  safeStrCpy(zippyPartner, player, sizeof(zippyPartner)/sizeof(zippyPartner[0]));
+	  SendToProgram(reply, &first);
 	}
 	return TRUE;
     }
@@ -506,17 +506,17 @@ int ZippyControl(buf, i)
 	/* This pattern works on FICS but not ICC */
 	player = StripHighlightAndTitle(star_match[0]);
 	if (strcmp(zippyPartner, player) != 0) {
-	    strcpy(zippyPartner, player);
-	    sprintf(reply, "partner %s\n", player);
-	    SendToProgram(reply, &first);
+	  safeStrCpy(zippyPartner, player, sizeof(zippyPartner)/sizeof(zippyPartner[0]));
+	  snprintf(reply, MSG_SIZ, "partner %s\n", player);
+	  SendToProgram(reply, &first);
 	}
-	sprintf(reply, "ptell %s\n", star_match[1]);
+	snprintf(reply, MSG_SIZ, "ptell %s\n", star_match[1]);
 	SendToProgram(reply, &first);
 	return TRUE;
     }
 
     if (looking_at(buf, i, "* tells you: *") ||
-	looking_at(buf, i, "* says: *")) 
+	looking_at(buf, i, "* says: *"))
     {
 	player = StripHighlightAndTitle(star_match[0]);
 	if (appData.zippyPassword[0] != NULLCHAR &&
@@ -538,7 +538,7 @@ int ZippyControl(buf, i)
 		    strlen(appData.zippyWrongPassword)) == 0) {
 	    p = star_match[1] + strlen(appData.zippyWrongPassword);
 	    while (*p == ' ') p++;
-	    sprintf(reply, "wrong %s\n", player);
+	    snprintf(reply, MSG_SIZ, "wrong %s\n", player);
 	    SendToICS(reply);
 	} else if (appData.zippyBughouse && first.initDone &&
 		   strcmp(player, zippyPartner) == 0) {
@@ -547,12 +547,12 @@ int ZippyControl(buf, i)
 	    SendToProgram("\n", &first);
 	} else if (strncmp(star_match[1], HI, 6) == 0) {
 	    extern char* programVersion;
-	    sprintf(reply, "%stell %s %s\n",
+	    snprintf(reply, MSG_SIZ, "%stell %s %s\n",
 		    ics_prefix, player, programVersion);
 	    SendToICS(reply);
 	} else if (strncmp(star_match[1], "W0W!! ", 6) == 0) {
 	    extern char* programVersion;
-	    sprintf(reply, "%stell %s %s\n", ics_prefix,
+	    snprintf(reply, MSG_SIZ, "%stell %s %s\n", ics_prefix,
 		    player, programVersion);
 	    SendToICS(reply);
 	} else if (appData.zippyTalk && (((unsigned) random() % 10) < 9)) {
@@ -573,7 +573,7 @@ int ZippyControl(buf, i)
 
     if (looking_at(buf, i, "* spoofs you:")) {
         player = StripHighlightAndTitle(star_match[0]);
-        sprintf(reply, "spoofedby %s\n", player);
+        snprintf(reply, MSG_SIZ, "spoofedby %s\n", player);
         SendToICS(reply);
     }
 
@@ -590,7 +590,7 @@ int ZippyConverse(buf, i)
 
     /* Shouts and emotes */
     if (looking_at(buf, i, "--> * *") ||
-	looking_at(buf, i, "* shouts: *")) 
+	looking_at(buf, i, "* shouts: *"))
     {
       if (appData.zippyTalk) {
 	char *player = StripHighlightAndTitle(star_match[0]);
@@ -598,7 +598,7 @@ int ZippyConverse(buf, i)
 	    return TRUE;
 	} else if (appData.zippyPinhead[0] != NULLCHAR &&
 		   StrCaseStr(star_match[1], appData.zippyPinhead) != NULL) {
-	    sprintf(reply, "insult %s\n", player);
+	  snprintf(reply, MSG_SIZ, "insult %s\n", player);
 	    SendToICS(reply);
 	} else if (ZippyCalled(star_match[1])) {
 	    Speak("shout", NULL);
@@ -693,7 +693,7 @@ int ZippyConverse(buf, i)
 	 atoi(star_match[0]) != 0) ||
 	looking_at(buf, i, "* has left a message for you") ||
 	looking_at(buf, i, "* just sent you a message")) {
-        sprintf(reply, "%smessages\n%sclearmessages *\n",
+      snprintf(reply, MSG_SIZ, "%smessages\n%sclearmessages *\n",
 		ics_prefix, ics_prefix);
 	SendToICS(reply);
 	return TRUE;
@@ -702,28 +702,28 @@ int ZippyConverse(buf, i)
     if (looking_at(buf, i, "Notification: * has arrived")) {
 	if (((unsigned) random() % 3) == 0) {
 	    char *player = StripHighlightAndTitle(star_match[0]);
-	    strcpy(lastgreet, player);
-	    sprintf(reply, "greet %s\n", player);
+	    safeStrCpy(lastgreet, player, sizeof(lastgreet)/sizeof(lastgreet[0]));
+	    snprintf(reply, MSG_SIZ, "greet %s\n", player);
 	    SendToICS(reply);
 	    Speak("tell", player);
 	}
-    }	
+    }
 
     if (looking_at(buf, i, "Notification: * has departed")) {
 	if (((unsigned) random() % 3) == 0) {
 	    char *player = StripHighlightAndTitle(star_match[0]);
-	    sprintf(reply, "farewell %s\n", player);
+	    snprintf(reply, MSG_SIZ, "farewell %s\n", player);
 	    SendToICS(reply);
 	}
-    }	
+    }
 
     if (looking_at(buf, i, "Not sent -- * is censoring you")) {
 	char *player = StripHighlightAndTitle(star_match[0]);
 	if (strcmp(player, lastgreet) == 0) {
-	    sprintf(reply, "%s-notify %s\n", ics_prefix, player);
+	  snprintf(reply, MSG_SIZ, "%s-notify %s\n", ics_prefix, player);
 	    SendToICS(reply);
 	}
-    }	
+    }
 
     if (looking_at(buf, i, "command is currently turned off")) {
 	appData.zippyUseI = 0;
@@ -760,8 +760,10 @@ void ZippyGameEnd(result, resultDetails)
       SendToICS("\n");
     }
     zippyLastGameEnd = time(0);
-    if(forwardMostMove < appData.zippyShortGame) 
-	strcpy(zippyOffender, zippyLastOpp); else zippyOffender[0] = 0; // [HGM] aborter
+    if(forwardMostMove < appData.zippyShortGame)
+      safeStrCpy(zippyOffender, zippyLastOpp, sizeof(zippyOffender)/sizeof(zippyOffender[0]));
+    else
+      zippyOffender[0] = 0; // [HGM] aborter
 }
 
 /*
@@ -791,7 +793,7 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
        easier to use the ICS formula feature instead. */
 
     if (variant == VariantLoadable) {
-        sprintf(buf,
+      snprintf(buf, MSG_SIZ,
 	 "%stell %s This computer can't play wild type %s\n%sdecline %s\n",
 		ics_prefix, opponent, swild, ics_prefix, opponent);
 	SendToICS(buf);
@@ -800,9 +802,9 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
     if (StrStr(appData.zippyVariants, varname) == NULL ||
               ((i=first.protocolVersion) != 1 && StrStr(first.variants, varname) == NULL) /* [HGM] zippyvar */
                                                           ) {
-        sprintf(buf,
+      snprintf(buf, MSG_SIZ,
 	 "%stell %s This computer can't play %s [%s], only %s\n%sdecline %s\n",
-		ics_prefix, opponent, swild, varname, 
+		ics_prefix, opponent, swild, varname,
                 i ? first.variants : appData.zippyVariants,                               /* [HGM] zippyvar */
 		ics_prefix, opponent);
 	SendToICS(buf);
@@ -815,14 +817,14 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
         /* Yes, and this isn't him.  Ignore challenge. */
 	return;
     }
-    
+
     /* Too many consecutive games with same opponent?  If so, make him
        wait until someone else has played or a timeout has elapsed. */
     if (appData.zippyMaxGames &&
 	strcmp(opponent, zippyLastOpp) == 0 &&
 	zippyConsecGames >= appData.zippyMaxGames &&
 	difftime(time(0), zippyLastGameEnd) < appData.zippyReplayTimeout) {
-      sprintf(buf, "%stell %s Sorry, you have just played %d consecutive games against %s.  To give others a chance, please wait %d seconds or until someone else has played.\n%sdecline %s\n",
+      snprintf(buf, MSG_SIZ,  "%stell %s Sorry, you have just played %d consecutive games against %s.  To give others a chance, please wait %d seconds or until someone else has played.\n%sdecline %s\n",
 	      ics_prefix, opponent, zippyConsecGames, ics_handle,
 	      appData.zippyReplayTimeout, ics_prefix, opponent);
       SendToICS(buf);
@@ -832,7 +834,7 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
     /* [HGM] aborter: opponent is cheater that aborts games he doesn't like on first move. Make him wait */
     if (strcmp(opponent, zippyOffender) == 0 &&
 	difftime(time(0), zippyLastGameEnd) < appData.zippyReplayTimeout) {
-      sprintf(buf, "%stell %s Sorry, your previous game against %s was rather short. "
+      snprintf(buf, MSG_SIZ,  "%stell %s Sorry, your previous game against %s was rather short. "
 		   " It will wait %d seconds to see if a tougher opponent comes along.\n%sdecline %s\n",
 	      ics_prefix, opponent, ics_handle,
 	      appData.zippyReplayTimeout, ics_prefix, opponent);
@@ -842,13 +844,13 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
 
     /* Engine not yet initialized or still thinking about last game? */
     if (!first.initDone || first.lastPing != first.lastPong) {
-      sprintf(buf, "%stell %s I'm not quite ready for a new game yet; try again soon.\n%sdecline %s\n",
+      snprintf(buf, MSG_SIZ,  "%stell %s I'm not quite ready for a new game yet; try again soon.\n%sdecline %s\n",
 	      ics_prefix, opponent, ics_prefix, opponent);
       SendToICS(buf);
       return;
     }
 
-    sprintf(buf, "%saccept %s\n", ics_prefix, opponent);
+    snprintf(buf, MSG_SIZ, "%saccept %s\n", ics_prefix, opponent);
     SendToICS(buf);
     if (appData.zippyTalk) {
       Speak("tell", opponent);
@@ -974,7 +976,7 @@ int ZippyMatch(buf, i)
     return FALSE;
 }
 
-/* Initialize chess program with data from the first board 
+/* Initialize chess program with data from the first board
  * of a new or resumed game.
  */
 void ZippyFirstBoard(moveNum, basetime, increment)
@@ -997,7 +999,7 @@ void ZippyFirstBoard(moveNum, basetime, increment)
 
     /* Send the variant command if needed */
     if (gameInfo.variant != VariantNormal) {
-      sprintf(buf, "variant %s\n", VariantName(gameInfo.variant));
+      snprintf(buf, MSG_SIZ,  "variant %s\n", VariantName(gameInfo.variant));
       SendToProgram(buf, &first);
     }
 
@@ -1008,7 +1010,7 @@ void ZippyFirstBoard(moveNum, basetime, increment)
       sentPos = TRUE;
     }
 
-    sprintf(buf, "level 0 %d %d\n", basetime, increment);
+    snprintf(buf, MSG_SIZ,  "level 0 %d %d\n", basetime, increment);
     SendToProgram(buf, &first);
 
     /* Count consecutive games from one opponent */
@@ -1016,7 +1018,7 @@ void ZippyFirstBoard(moveNum, basetime, increment)
       zippyConsecGames++;
     } else {
       zippyConsecGames = 1;
-      strcpy(zippyLastOpp, opp);
+      safeStrCpy(zippyLastOpp, opp, sizeof(zippyLastOpp)/sizeof(zippyLastOpp[0]));
     }
 
     /* Send the "computer" command if the opponent is in the list
@@ -1032,15 +1034,15 @@ void ZippyFirstBoard(moveNum, basetime, increment)
        message from ICS." Send 0 in that case */
     w = (gameInfo.whiteRating >= 0) ? gameInfo.whiteRating : 0;
     b = (gameInfo.blackRating >= 0) ? gameInfo.blackRating : 0;
-    
+
     firstMove = FALSE;
     if (gameMode == IcsPlayingWhite) {
         if (first.sendName) {
-	  sprintf(buf, "name %s\n", gameInfo.black);
+	  snprintf(buf, MSG_SIZ,  "name %s\n", gameInfo.black);
 	  SendToProgram(buf, &first);
 	}
-	strcpy(ics_handle, gameInfo.white);
-	sprintf(buf, "rating %d %d\n", w, b);
+	safeStrCpy(ics_handle, gameInfo.white, MSG_SIZ);
+	snprintf(buf, MSG_SIZ,  "rating %d %d\n", w, b);
 	SendToProgram(buf, &first);
 	if (sentPos) {
 	    /* Position sent above, engine is in force mode */
@@ -1087,11 +1089,11 @@ void ZippyFirstBoard(moveNum, basetime, increment)
 	}
     } else if (gameMode == IcsPlayingBlack) {
         if (first.sendName) {
-	  sprintf(buf, "name %s\n", gameInfo.white);
+	  snprintf(buf, MSG_SIZ,  "name %s\n", gameInfo.white);
 	  SendToProgram(buf, &first);
 	}
-	strcpy(ics_handle, gameInfo.black);
-	sprintf(buf, "rating %d %d\n", b, w);
+	safeStrCpy(ics_handle, gameInfo.black, MSG_SIZ);
+	snprintf(buf, MSG_SIZ,  "rating %d %d\n", b, w);
 	SendToProgram(buf, &first);
 	if (sentPos) {
 	    /* Position sent above, engine is in force mode */
@@ -1123,17 +1125,17 @@ void ZippyFirstBoard(moveNum, basetime, increment)
 	} else {
 	    /* Position not sent above, move list might be sent later */
 	    /* Nothing needs to be done here */
-	}	
+	}
     }
 
     if(bookHit) { // [HGM] book: simulate book reply
 	static char bookMove[MSG_SIZ]; // a bit generous?
 
-	programStats.depth = programStats.nodes = programStats.time = 
+	programStats.depth = programStats.nodes = programStats.time =
 	programStats.score = programStats.got_only_move = 0;
 	sprintf(programStats.movelist, "%s (xbook)", bookHit);
 
-	strcpy(bookMove, "move ");
+	safeStrCpy(bookMove, "move ", sizeof(bookMove)/sizeof(bookMove[0]));
 	strcat(bookMove, bookHit);
 	HandleMachineMove(bookMove, &first);
     }
@@ -1146,7 +1148,7 @@ ZippyHoldings(white_holding, black_holding, new_piece)
 {
     char buf[MSG_SIZ];
     if (gameMode != IcsPlayingBlack && gameMode != IcsPlayingWhite) return;
-    sprintf(buf, "holding [%s] [%s] %s\n",
+    snprintf(buf, MSG_SIZ,  "holding [%s] [%s] %s\n",
 	    white_holding, black_holding, new_piece);
     SendToProgram(buf, &first);
 }
